Struct av1an_cli::CliOpts [−][src]
pub struct CliOpts {Show 35 fields
pub input: PathBuf,
pub temp: Option<PathBuf>,
pub output_file: Option<PathBuf>,
pub concat: ConcatMethod,
pub quiet: bool,
pub verbose: bool,
pub logging: Option<String>,
pub resume: bool,
pub keep: bool,
pub chunk_method: Option<ChunkMethod>,
pub scenes: Option<PathBuf>,
pub split_method: SplitMethod,
pub sc_method: ScenecutMethod,
pub sc_downscale_height: Option<usize>,
pub extra_split: usize,
pub min_scene_len: usize,
pub passes: Option<u8>,
pub video_params: Option<String>,
pub encoder: Encoder,
pub workers: usize,
pub force: bool,
pub ffmpeg_filter_args: Option<String>,
pub audio_params: Option<String>,
pub pix_format: Pixel,
pub vmaf: bool,
pub vmaf_path: Option<PathBuf>,
pub vmaf_res: String,
pub vmaf_threads: Option<usize>,
pub target_quality: Option<f64>,
pub probes: u32,
pub probing_rate: u32,
pub probe_slow: bool,
pub min_q: Option<u32>,
pub max_q: Option<u32>,
pub vmaf_filter: Option<String>,
}Expand description
Cross-platform command-line AV1 / VP9 / HEVC / H264 encoding framework with per-scene quality encoding
Fields
input: PathBufInput file or vapoursynth (.py, .vpy) script
temp: Option<PathBuf>Temporary directory to use
output_file: Option<PathBuf>Specify output file
concat: ConcatMethodMethod to use for concatenating encoded chunks
quiet: boolDisable printing progress to the terminal
verbose: boolPrint extra progress info and stats to terminal
logging: Option<String>Specify this option to log to a non-default file
resume: boolResume previous session
keep: boolDo not delete the temporary folder after encoding has finished
chunk_method: Option<ChunkMethod>Method for creating chunks
scenes: Option<PathBuf>File location for scenes
split_method: SplitMethodMethod used to detect scenecuts. av-scenechange uses an algorithm to analyze which frames of
the video are the start of new scenes, while none disable scene detection entirely (and only
rely on -x/--extra-split to add extra scenecuts).
sc_method: ScenecutMethodSpecify scenecut method
Standard: Most accurate, still reasonably fast. Fast: Very fast, but less accurate.
sc_downscale_height: Option<usize>Optional downscaling for scenecut detection. Specify as the desired maximum height to scale to (e.g. “720” to downscale to 720p–this will leave lower resolution content untouched). Downscaling will improve speed but lower scenecut accuracy, especially when scaling to very low resolutions.
extra_split: usizeMaximum scene length
When a scenecut is found whose distance to the previous scenecut is greater than the value specified by this option, one or more extra splits (scenecuts) are added. Set this option to 0 to disable adding extra splits.
min_scene_len: usizeMinimum number of frames for a scenecut
passes: Option<u8>Specify number encoding passes
When using vpx or aom with RT, set this option to 1.
video_params: Option<String>Video encoder parameters
encoder: EncoderVideo encoder to use
workers: usizeNumber of workers. 0 = automatic
force: boolDo not check if the encoder arguments specified by --video-params are valid
ffmpeg_filter_args: Option<String>FFmpeg filter options
audio_params: Option<String>Audio encoding parameters. If not specified, “-c:a copy” is used
Example to encode the audio with libopus: -a=“-c:a libopus -b:a 128k -ac 2”
pix_format: PixelFFmpeg pixel format
vmaf: boolCalculate and plot the VMAF of the encode
vmaf_path: Option<PathBuf>Path to VMAF model
vmaf_res: StringResolution used for VMAF calculation
vmaf_threads: Option<usize>Number of threads to use for VMAF calculation
target_quality: Option<f64>VMAF score to target
probes: u32Maximum number of probes allowed for target quality
probing_rate: u32Framerate for probes, 1 - original
probe_slow: boolUse encoding settings for probes
min_q: Option<u32>Min q for target quality
max_q: Option<u32>Max q for target quality
vmaf_filter: Option<String>Filter applied to source at VMAF calcualation. This option should be specified if the source is cropped.